@@ -238,7 +238,7 @@ class AsyncChannel(ChannelBase):
 
         bytes_channel_input = channel_input.encode()
 
-        with self.transport.session_lock:
+        with self.session_lock:
             self.logger.info(
                 f"Attempting to send input: {channel_input}; strip_prompt: {strip_prompt}"
             )
@@ -285,7 +285,7 @@ class AsyncChannel(ChannelBase):
             channel_output.encode() for channel_output in expected_outputs or []
         ]
 
-        with self.transport.session_lock:
+        with self.session_lock:
             self.transport.write(channel_input=channel_input)
             self.logger.debug(f"Write: {repr(channel_input)}")
             await self._read_until_input(channel_input=bytes_channel_input)
@@ -364,29 +364,28 @@ class AsyncChannel(ChannelBase):
         """
         self._pre_send_inputs_interact(interact_events=interact_events)
 
-        self.transport.session_lock.acquire()
-        output = b""
-        for interact_event in interact_events:
-            channel_input = interact_event[0]
-            bytes_channel_input = channel_input.encode()
-            channel_response = interact_event[1]
-            try:
-                hidden_input = interact_event[2]
-            except IndexError:
-                hidden_input = False
-            self.logger.info(
-                f"Attempting to send input interact: {channel_input}; "
-                f"\texpecting: {channel_response};"
-                f"\thidden_input: {hidden_input}"
-            )
-            self.transport.write(channel_input=channel_input)
-            self.logger.debug(f"Write: {repr(channel_input)}")
-            if not channel_response or hidden_input is True:
-                self._send_return()
-            else:
-                output += await self._read_until_input(channel_input=bytes_channel_input)
-                self._send_return()
-            output += await self._read_until_prompt(prompt=channel_response)
-        # wait to release lock until after "interact" session is complete
-        self.transport.session_lock.release()
+        with self.session_lock:
+            output = b""
+            for interact_event in interact_events:
+                channel_input = interact_event[0]
+                bytes_channel_input = channel_input.encode()
+                channel_response = interact_event[1]
+                try:
+                    hidden_input = interact_event[2]
+                except IndexError:
+                    hidden_input = False
+                self.logger.info(
+                    f"Attempting to send input interact: {channel_input}; "
+                    f"\texpecting: {channel_response};"
+                    f"\thidden_input: {hidden_input}"
+                )
+                self.transport.write(channel_input=channel_input)
+                self.logger.debug(f"Write: {repr(channel_input)}")
+                if not channel_response or hidden_input is True:
+                    self._send_return()
+                else:
+                    output += await self._read_until_input(channel_input=bytes_channel_input)
+                    self._send_return()
+                output += await self._read_until_prompt(prompt=channel_response)
+
         return self._post_send_inputs_interact(output=output)
