@@ -2,9 +2,10 @@
 import re
 from abc import ABC
 from logging import getLogger
+from threading import Lock
 from typing import List, Optional, Tuple, Union
 
-from scrapli.helper import get_prompt_pattern, normalize_lines
+from scrapli.helper import attach_duplicate_log_filter, get_prompt_pattern, normalize_lines
 from scrapli.transport.async_transport import AsyncTransport
 from scrapli.transport.transport import Transport
 
@@ -62,6 +63,7 @@ class ChannelBase(ABC):
 
         """
         self.logger = getLogger(f"scrapli.channel-{transport.host}")
+        attach_duplicate_log_filter(logger=self.logger)
 
         self.transport = transport
         self.comms_prompt_pattern = comms_prompt_pattern
@@ -70,6 +72,8 @@ class ChannelBase(ABC):
         self.comms_auto_expand = comms_auto_expand
         self.timeout_ops = timeout_ops
 
+        self.session_lock = Lock()
+
     def __str__(self) -> str:
         """
         Magic str method for Channel
@@ -102,6 +106,7 @@ class ChannelBase(ABC):
         """
         class_dict = self.__dict__.copy()
         class_dict.pop("transport")
+        class_dict["session_lock"] = self.session_lock.locked()
         class_dict["logger"] = self.logger.name
         return f"scrapli Channel {class_dict}"
 
