@@ -76,7 +76,7 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         """
         self._pre_escalate(escalate_priv=escalate_priv)
 
-        if escalate_priv.escalate_auth is True:
+        if escalate_priv.escalate_auth is True and self.auth_secondary:
             await super().send_interactive(
                 interact_events=[
                     (escalate_priv.escalate, escalate_priv.escalate_prompt, False),
@@ -146,6 +146,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         command: str,
         strip_prompt: bool = True,
         failed_when_contains: Optional[Union[str, List[str]]] = None,
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> Response:
         """
         Send a command
@@ -156,6 +158,9 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             command: string to send to device in privilege exec mode
             strip_prompt: True/False strip prompt from returned output
             failed_when_contains: string or list of strings indicating failure if found in response
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed
 
         Returns:
             Response: Scrapli Response object
@@ -170,8 +175,11 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         if failed_when_contains is None:
             failed_when_contains = self.failed_when_contains
 
-        response = await super().send_command(
-            command=command, strip_prompt=strip_prompt, failed_when_contains=failed_when_contains
+        response: Response = await super().send_command(
+            command=command,
+            strip_prompt=strip_prompt,
+            failed_when_contains=failed_when_contains,
+            timeout_ops=timeout_ops,
         )
 
         self._update_response(response)
@@ -184,6 +192,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         strip_prompt: bool = True,
         failed_when_contains: Optional[Union[str, List[str]]] = None,
         stop_on_failed: bool = False,
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> ScrapliMultiResponse:
         """
         Send multiple commands
@@ -196,6 +206,10 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             failed_when_contains: string or list of strings indicating failure if found in response
             stop_on_failed: True/False stop executing commands if a command fails, returns results
                 as of current execution
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed. Note that this is the timeout value PER COMMAND sent, not for the total
+                of the commands being sent!
 
         Returns:
             ScrapliMultiResponse: Scrapli MultiResponse object
@@ -215,6 +229,7 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             strip_prompt=strip_prompt,
             failed_when_contains=failed_when_contains,
             stop_on_failed=stop_on_failed,
+            timeout_ops=timeout_ops,
         )
 
         for response in responses:
@@ -228,6 +243,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         strip_prompt: bool = True,
         failed_when_contains: Optional[Union[str, List[str]]] = None,
         stop_on_failed: bool = False,
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> ScrapliMultiResponse:
         """
         Send command(s) from file
@@ -238,6 +255,10 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             failed_when_contains: string or list of strings indicating failure if found in response
             stop_on_failed: True/False stop executing commands if a command fails, returns results
                 as of current execution
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed. Note that this is the timeout value PER COMMAND sent, not for the total
+                of the commands being sent!
 
         Returns:
             ScrapliMultiResponse: Scrapli MultiResponse object
@@ -246,13 +267,18 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             N/A
 
         """
-        commands = self._pre_send_commands_from_file(file=file)
+        if self._current_priv_level.name != self.default_desired_privilege_level:
+            await self.acquire_priv(desired_priv=self.default_desired_privilege_level)
 
-        return await self.send_commands(
-            commands=commands,
+        if failed_when_contains is None:
+            failed_when_contains = self.failed_when_contains
+
+        return await super().send_commands_from_file(
+            file=file,
             strip_prompt=strip_prompt,
             failed_when_contains=failed_when_contains,
             stop_on_failed=stop_on_failed,
+            timeout_ops=timeout_ops,
         )
 
     async def send_interactive(
@@ -361,6 +387,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         failed_when_contains: Optional[Union[str, List[str]]] = None,
         stop_on_failed: bool = False,
         privilege_level: str = "",
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> Response:
         """
         Send configuration(s)
@@ -378,6 +406,10 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
                 JunosDriver. You can also pass in a name of a configuration session such as
                 "my-config-session" if you have registered a session using the
                 "register_config_session" method of the EOSDriver or NXOSDriver.
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed. Note that this is the timeout value PER CONFIG sent, not for the total
+                of the configs being sent!
 
         Returns:
             Response: Scrapli Response object
@@ -395,6 +427,7 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             failed_when_contains=failed_when_contains,
             stop_on_failed=stop_on_failed,
             privilege_level=privilege_level,
+            timeout_ops=timeout_ops,
         )
         return self._post_send_config(config=config, multi_response=multi_response)
 
@@ -405,6 +438,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         failed_when_contains: Optional[Union[str, List[str]]] = None,
         stop_on_failed: bool = False,
         privilege_level: str = "",
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> ScrapliMultiResponse:
         """
         Send configuration(s)
@@ -422,6 +457,10 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
                 JunosDriver. You can also pass in a name of a configuration session such as
                 "my-config-session" if you have registered a session using the
                 "register_config_session" method of the EOSDriver or NXOSDriver.
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed. Note that this is the timeout value PER CONFIG sent, not for the total
+                of the configs being sent!
 
         Returns:
             ScrapliMultiResponse: Scrapli MultiResponse object
@@ -446,6 +485,7 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
                 command=config,
                 strip_prompt=strip_prompt,
                 failed_when_contains=failed_when_contains,
+                timeout_ops=timeout_ops,
             )
             responses.append(response)
             if response.failed is True:
@@ -465,6 +505,8 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
         failed_when_contains: Optional[Union[str, List[str]]] = None,
         stop_on_failed: bool = False,
         privilege_level: str = "",
+        *,
+        timeout_ops: Optional[float] = None,
     ) -> ScrapliMultiResponse:
         """
         Send configuration(s) from a file
@@ -482,6 +524,10 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
                 in a name of a configuration session such as "session_mysession" if you have
                 registered a session using the "register_config_session" method of the EOSDriver or
                 NXOSDriver.
+            timeout_ops: timeout ops value for this operation; only sets the timeout_ops value for
+                the duration of the operation, value is reset to initial value after operation is
+                completed. Note that this is the timeout value PER CONFIG sent, not for the total
+                of the configs being sent!
 
         Returns:
             ScrapliMultiResponse: Scrapli MultiResponse object
@@ -498,4 +544,5 @@ class AsyncNetworkDriver(AsyncGenericDriver, NetworkDriverBase):
             failed_when_contains=failed_when_contains,
             stop_on_failed=stop_on_failed,
             privilege_level=privilege_level,
+            timeout_ops=timeout_ops,
         )
