@@ -28,10 +28,6 @@ TRANSPORT_ARGS: Dict[str, Tuple[str, ...]] = {
 TRANSPORT_BASE_ARGS = (
     "host",
     "port",
-    "keepalive",
-    "keepalive_interval",
-    "keepalive_type",
-    "keepalive_pattern",
     "timeout_socket",
     "timeout_transport",
     "timeout_exit",
@@ -54,15 +50,12 @@ class ScrapeBase:
         timeout_transport: int = 10,
         timeout_ops: float = 30,
         timeout_exit: bool = True,
-        keepalive: bool = False,
-        keepalive_interval: int = 30,
-        keepalive_type: str = "network",
-        keepalive_pattern: str = "\005",
         comms_prompt_pattern: str = r"^[a-z0-9.\-@()/:]{1,48}[#>$]\s*$",
         comms_return_char: str = "\n",
         comms_ansi: bool = False,
         ssh_config_file: Union[str, bool] = False,
         ssh_known_hosts_file: Union[str, bool] = False,
+        on_init: Optional[Callable[..., Any]] = None,
         on_open: Optional[Callable[..., Any]] = None,
         on_close: Optional[Callable[..., Any]] = None,
         transport: str = "system",
@@ -96,19 +89,6 @@ class ScrapeBase:
             timeout_exit: True/False close transport if timeout encountered. If False and keepalives
                 are in use, keepalives will prevent program from exiting so you should be sure to
                 catch Timeout exceptions and handle them appropriately
-            keepalive: whether or not to try to keep session alive
-            keepalive_interval: interval to use for session keepalives
-            keepalive_type: network|standard -- 'network' sends actual characters over the
-                transport channel. This is useful for network-y type devices that may not support
-                'standard' keepalive mechanisms. 'standard' attempts to use whatever 'standard'
-                keepalive mechanisms are available in the selected transport mechanism. Check the
-                transport documentation for details on what is supported and/or how it is
-                implemented for any given transport driver
-            keepalive_pattern: pattern to send to keep network channel alive. Default is
-                u'\005' which is equivalent to 'ctrl+e'. This pattern moves cursor to end of the
-                line which should be an innocuous pattern. This will only be entered *if* a lock
-                can be acquired. This is only applicable if using keepalives and if the keepalive
-                type is 'network'
             comms_prompt_pattern: raw string regex pattern -- preferably use `^` and `$` anchors!
                 this is the single most important attribute here! if this does not match a prompt,
                 scrapli will not work!
@@ -123,6 +103,14 @@ class ScrapeBase:
                 or False to ignore default ssh config file
             ssh_known_hosts_file: string to path for ssh known hosts file, True to use default known
                 file locations. Only applicable/needed if `auth_strict_key` is set to True
+            on_init: callable that accepts the class instance as its only argument. this callable,
+                if provided, is executed as the last step of object instantiation -- its purpose is
+                primarily to provide a mechanism for scrapli community platforms to have an easy way
+                to modify initialization arguments/object attributes without needing to create a
+                class that extends the driver, instead allowing the community platforms to simply
+                build from the GenericDriver or NetworkDriver classes, and pass this callable to do
+                things such as appending to a username (looking at you RouterOS!!). Note that this
+                is *always* a synchronous function (even for asyncio drivers)!
             on_open: callable that accepts the class instance as its only argument. this callable,
                 if provided, is executed immediately after authentication is completed. Common use
                 cases for this callable would be to disable paging or accept any kind of banner
@@ -173,18 +161,13 @@ class ScrapeBase:
             timeout_exit=timeout_exit,
         )
         self._timeout_ops: float = self._initialization_args["timeout_ops"]
-        self._setup_keepalive(
-            keepalive=keepalive,
-            keepalive_type=keepalive_type,
-            keepalive_interval=keepalive_interval,
-            keepalive_pattern=keepalive_pattern,
-        )
+
         self._setup_comms(
             comms_prompt_pattern=comms_prompt_pattern,
             comms_return_char=comms_return_char,
             comms_ansi=comms_ansi,
         )
-        self._setup_callables(on_open=on_open, on_close=on_close)
+        self._setup_callables(on_init=on_init, on_open=on_open, on_close=on_close)
 
         if transport not in ("system", "telnet"):
             self.logger.info(f"Non-core transport `{transport}` selected")
@@ -214,6 +197,9 @@ class ScrapeBase:
                 continue
             self.channel_args[arg] = self._initialization_args.get(arg)
 
+        if self.on_init:
+            self.on_init()
+
     def __str__(self) -> str:
         """
         Magic str method for Scrape
@@ -259,15 +245,12 @@ class ScrapeBase:
             f"timeout_transport={self._initialization_args['timeout_transport']!r}, "
             f"timeout_ops={self._initialization_args['timeout_ops']!r}, "
             f"timeout_exit={self._initialization_args['timeout_exit']!r}, "
-            f"keepalive={self._initialization_args['keepalive']!r}, "
-            f"keepalive_interval={self._initialization_args['keepalive_interval']!r}, "
-            f"keepalive_type={self._initialization_args['keepalive_type']!r}, "
-            f"keepalive_pattern={self._initialization_args['keepalive_pattern']!r}, "
             f"comms_prompt_pattern={self._initialization_args['comms_prompt_pattern']!r}, "
             f"comms_return_char={self._initialization_args['comms_return_char']!r}, "
             f"comms_ansi={self._initialization_args['comms_ansi']!r}, "
             f"ssh_config_file={self._initialization_args.get('ssh_config_file')!r}, "
             f"ssh_known_hosts_file={self._initialization_args.get('ssh_known_hosts_file')!r}, "
+            f"on_init={self.on_init!r}, "
             f"on_open={self.on_open!r}, "
             f"on_close={self.on_close!r}, "
             f"transport={self._transport!r}, "
@@ -380,37 +363,6 @@ class ScrapeBase:
         self._initialization_args["timeout_ops"] = float(timeout_ops)
         self._initialization_args["timeout_exit"] = timeout_exit
 
-    def _setup_keepalive(
-        self, keepalive: bool, keepalive_type: str, keepalive_interval: int, keepalive_pattern: str
-    ) -> None:
-        """
-        Parse and setup keepalive attributes
-
-        Args:
-            keepalive: keepalive to parse/set
-            keepalive_type: keepalive_type to parse/set
-            keepalive_interval: keepalive_interval to parse/set
-            keepalive_pattern: keepalive_pattern to parse/set
-
-        Returns:
-            N/A  # noqa: DAR202
-
-        Raises:
-            TypeError: if keepalive is not a bool
-            ValueError: if keepalive_type is not valid
-
-        """
-        if not isinstance(keepalive, bool):
-            raise TypeError(f"`keepalive` should be bool, got {type(keepalive)}")
-        if keepalive_type not in ["network", "standard"]:
-            raise ValueError(
-                f"`{keepalive_type}` is an invalid keepalive_type; must be 'network' or 'standard'"
-            )
-        self._initialization_args["keepalive"] = keepalive
-        self._initialization_args["keepalive_interval"] = int(keepalive_interval)
-        self._initialization_args["keepalive_type"] = keepalive_type
-        self._initialization_args["keepalive_pattern"] = keepalive_pattern
-
     def _setup_comms(
         self, comms_prompt_pattern: str, comms_return_char: str, comms_ansi: bool
     ) -> None:
@@ -442,12 +394,16 @@ class ScrapeBase:
         self._initialization_args["comms_ansi"] = comms_ansi
 
     def _setup_callables(
-        self, on_open: Optional[Callable[..., Any]], on_close: Optional[Callable[..., Any]]
+        self,
+        on_init: Optional[Callable[..., Any]],
+        on_open: Optional[Callable[..., Any]],
+        on_close: Optional[Callable[..., Any]],
     ) -> None:
         """
         Parse and setup callables (on_open/on_close)
 
         Args:
+            on_init: on_init to parse/set
             on_open: on_open to parse/set
             on_close: on_close to parse/set
 
@@ -458,12 +414,16 @@ class ScrapeBase:
             TypeError: if port is not an integer
 
         """
+        if on_init is not None and not callable(on_init):
+            raise TypeError(f"`on_init` must be a callable, got {type(on_init)}")
         if on_open is not None and not callable(on_open):
             raise TypeError(f"`on_open` must be a callable, got {type(on_open)}")
         if on_close is not None and not callable(on_close):
             raise TypeError(f"`on_close` must be a callable, got {type(on_close)}")
+        self.on_init = on_init
         self.on_open = on_open
         self.on_close = on_close
+        self._initialization_args["on_init"] = on_init
         self._initialization_args["on_open"] = on_open
         self._initialization_args["on_close"] = on_close
 
