@@ -1,9 +1,11 @@
 """scrapli.transport"""
+from scrapli.transport.async_transport import AsyncTransport
 from scrapli.transport.systemssh import SYSTEM_SSH_TRANSPORT_ARGS, SystemSSHTransport
 from scrapli.transport.telnet import TELNET_TRANSPORT_ARGS, TelnetTransport
 from scrapli.transport.transport import Transport
 
 __all__ = (
+    "AsyncTransport",
     "Transport",
     "SystemSSHTransport",
     "SYSTEM_SSH_TRANSPORT_ARGS",
