@@ -64,6 +64,17 @@ def test_read_until_prompt(sync_cisco_iosxe_conn):
     assert found_prompt == expected_prompt
 
 
+def test_read_until_prompt_or_time(sync_cisco_iosxe_conn):
+    sync_cisco_iosxe_conn.open()
+    chunk = "this is some input for read chunk to read"
+    sync_cisco_iosxe_conn.transport.write(chunk)
+    sync_cisco_iosxe_conn.transport.write(sync_cisco_iosxe_conn.channel.comms_return_char)
+    read_chunk = sync_cisco_iosxe_conn.channel._read_until_prompt_or_time(
+        channel_outputs=[b"chunk to read"]
+    )
+    assert chunk.encode() in read_chunk
+
+
 def test_get_prompt(sync_cisco_iosxe_conn):
     expected_prompt = TEST_CASES["cisco_iosxe"]["test_get_prompt"]["privilege_exec"]
     sync_cisco_iosxe_conn.open()
@@ -72,7 +83,9 @@ def test_get_prompt(sync_cisco_iosxe_conn):
 
 
 @pytest.mark.parametrize(
-    "strip_prompt", [True, False], ids=["strip_prompt", "no_strip_prompt"],
+    "strip_prompt",
+    [True, False],
+    ids=["strip_prompt", "no_strip_prompt"],
 )
 def test_send_input(sync_cisco_iosxe_conn, strip_prompt):
     expected_raw = TEST_CASES["cisco_iosxe"]["test_send_input"]["raw_result"]
@@ -99,3 +112,23 @@ def test_send_inputs_interact(sync_cisco_iosxe_conn):
     )
     assert raw_result == expected_raw.encode()
     assert processed_result == expected_processed.encode()
+
+
+@pytest.mark.parametrize(
+    "strip_prompt",
+    [True, False],
+    ids=["strip_prompt", "no_strip_prompt"],
+)
+def test_send_input_and_read(sync_cisco_iosxe_conn, strip_prompt):
+    expected_raw = TEST_CASES["cisco_iosxe"]["test_send_input"]["raw_result"]
+    expected_processed = (
+        TEST_CASES["cisco_iosxe"]["test_send_input"]["processed_result"]["strip"]
+        if strip_prompt
+        else TEST_CASES["cisco_iosxe"]["test_send_input"]["processed_result"]["no_strip"]
+    )
+    sync_cisco_iosxe_conn.open()
+    raw_result, processed_result = sync_cisco_iosxe_conn.channel.send_input_and_read(
+        channel_input="show version", strip_prompt=strip_prompt
+    )
+    assert raw_result == expected_raw.encode()
+    assert processed_result == expected_processed.encode()
