@@ -2,7 +2,7 @@ import sys
 
 import pytest
 
-from scrapli.exceptions import ConnectionNotOpened, ScrapliAuthenticationFailed
+from scrapli.exceptions import ConnectionNotOpened
 from scrapli.transport import TelnetTransport
 from scrapli.transport.telnet import ScrapliTelnet
 
@@ -26,18 +26,11 @@ def test_creation():
 @pytest.mark.skipif(sys.platform.startswith("win"), reason="skipping on windows")
 def test_open_failure():
     conn = TelnetTransport("localhost", port=23)
-    with pytest.raises(ScrapliAuthenticationFailed) as exc:
+    with pytest.raises(ConnectionNotOpened) as exc:
         conn.open()
     assert str(exc.value) == "Failed to open telnet session to host localhost, connection refused"
 
 
-def test_keepalive_standard():
-    conn = TelnetTransport("localhost")
-    with pytest.raises(NotImplementedError) as exc:
-        conn._keepalive_standard()
-    assert str(exc.value) == "No 'standard' keepalive mechanism for telnet."
-
-
 @pytest.mark.parametrize(
     "method_name",
     ["read", "write", "set_timeout"],
@@ -47,7 +40,7 @@ def test_requires_open(method_name):
     conn = TelnetTransport("localhost")
     method = getattr(conn, method_name)
     with pytest.raises(ConnectionNotOpened):
-        if method_name == "write":
-            method("blah")
-        else:
+        if method_name == "read":
             method()
+        else:
+            method("blah")
